CupertinoLocalizations class abstract

Defines the localized resource values used by the Cupertino widgets.

See also:

Implementers

Constructors

CupertinoLocalizations()

Properties

alertDialogLabel → String
The term used by the system to announce dialog alerts.
no setter
anteMeridiemAbbreviation → String
The abbreviation for ante meridiem (before noon) shown in the time picker.
no setter
backButtonLabel → String
The label for the back button, used in CupertinoNavigationBar and CupertinoSliverNavigationBar.
no setter
cancelButtonLabel → String
The label for the cancel button in modal views, used in CupertinoNavigationBar and CupertinoSliverNavigationBar.
no setter
clearButtonLabel → String
The term used for clearing a field.
no setter
collapsedHint → String
The semantics hint to describe the CupertinoExpansionTile collapsed state.
no setter
copyButtonLabel → String
The term used for copying.
no setter
cutButtonLabel → String
The term used for cutting.
no setter
datePickerDateOrder → DatePickerDateOrder
The order of the date elements that will be shown in CupertinoDatePicker.
no setter
datePickerDateTimeOrder → DatePickerDateTimeOrder
The order of the time elements that will be shown in CupertinoDatePicker.
no setter
expandedHint → String
The semantics hint to describe the CupertinoExpansionTile expanded state.
no setter
expansionTileCollapsedHint → String
The semantics hint to describe the tap action on a collapsed CupertinoExpansionTile on iOS and macOS. This is appended to the expandedHint hint to provide a more detailed description of the action, e.g. "Collapsed double tap to expand".
no setter
expansionTileCollapsedTapHint → String
The semantics hint to describe the tap action on a collapsed CupertinoExpansionTile.
no setter
expansionTileExpandedHint → String
The semantics hint to describe the tap action on an expanded CupertinoExpansionTile on iOS and macOS. This is appended to the collapsedHint hint to provide a more detailed description of the action, e.g. "Expanded double tap to collapse".
no setter
expansionTileExpandedTapHint → String
The semantics hint to describe the tap action on an expanded CupertinoExpansionTile.
no setter
hashCode → int
The hash code for this object.
no setterinherited
lookUpButtonLabel → String
The term used for looking up a selection.
no setter
Label read out by accessibility tools (VoiceOver) for a context menu to indicate that a tap outside dismisses the context menu.
no setter
modalBarrierDismissLabel → String
Label read out by accessibility tools (VoiceOver) for a modal barrier to indicate that a tap dismisses the barrier.
no setter
noSpellCheckReplacementsLabel → String
Label that appears in the Cupertino toolbar when the spell checker couldn't find any replacements for the current word.
no setter
pasteButtonLabel → String
The term used for pasting.
no setter
postMeridiemAbbreviation → String
The abbreviation for post meridiem (after noon) shown in the time picker.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchTextFieldPlaceholderLabel → String
The default placeholder used in CupertinoSearchTextField.
no setter
searchWebButtonLabel → String
The term used for launching a web search on a selection.
no setter
selectAllButtonLabel → String
The term used for selecting everything.
no setter
shareButtonLabel → String
The term used for launching a web search on a selection.
no setter
timerPickerHourLabels → List<String>
All possible hour labels that appears next to the hour picker in CupertinoTimerPicker
no setter
timerPickerMinuteLabels → List<String>
All possible minute labels that appears next to the minute picker in CupertinoTimerPicker
no setter
timerPickerSecondLabels → List<String>
All possible second labels that appears next to the second picker in CupertinoTimerPicker
no setter
todayLabel → String
Label shown in date pickers when the date is today.
no setter

Methods

datePickerDayOfMonth(int dayIndex, [int? weekDay]) → String
Day of month that is shown in CupertinoDatePicker spinner corresponding to the given day index.
datePickerHour(int hour) → String
Hour that is shown in CupertinoDatePicker spinner corresponding to the given hour value.
datePickerHourSemanticsLabel(int hour) → String?
Semantics label for the given hour value in CupertinoDatePicker.
datePickerMediumDate(DateTime date) → String
The medium-width date format that is shown in CupertinoDatePicker spinner. Abbreviates month and days of week.
datePickerMinute(int minute) → String
Minute that is shown in CupertinoDatePicker spinner corresponding to the given minute value.
datePickerMinuteSemanticsLabel(int minute) → String?
Semantics label for the given minute value in CupertinoDatePicker.
datePickerMonth(int monthIndex) → String
Month that is shown in CupertinoDatePicker spinner corresponding to the given month index.
datePickerStandaloneMonth(int monthIndex) → String
Month that is shown in CupertinoDatePicker spinner corresponding to the given month index in CupertinoDatePickerMode.monthYear mode.
datePickerYear(int yearIndex) → String
Year that is shown in CupertinoDatePicker spinner corresponding to the given year index.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tabSemanticsLabel({required int tabIndex, required int tabCount}) → String
The accessibility label used on a tab in a CupertinoTabBar.
timerPickerHour(int hour) → String
Hour that is shown in CupertinoTimerPicker corresponding to the given hour value.
timerPickerHourLabel(int hour) → String?
Label that appears next to the hour picker in CupertinoTimerPicker when selected hour value is hour. This function will deal with pluralization based on the hour parameter.
timerPickerMinute(int minute) → String
Minute that is shown in CupertinoTimerPicker corresponding to the given minute value.
timerPickerMinuteLabel(int minute) → String?
Label that appears next to the minute picker in CupertinoTimerPicker when selected minute value is minute. This function will deal with pluralization based on the minute parameter.
timerPickerSecond(int second) → String
Second that is shown in CupertinoTimerPicker corresponding to the given second value.
timerPickerSecondLabel(int second) → String?
Label that appears next to the minute picker in CupertinoTimerPicker when selected minute value is second. This function will deal with pluralization based on the second parameter.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → CupertinoLocalizations
The CupertinoLocalizations from the closest Localizations instance that encloses the given context.